@@ -1,8 +1,10 @@
-use crate::decor::InternalString;
-use crate::parser;
-use crate::table::{Item, Iter, Table};
 use std::str::FromStr;
 
+use crate::parser;
+use crate::repr::InternalString;
+use crate::table::Iter;
+use crate::{Item, Table};
+
 /// Type representing a TOML document
 #[derive(Debug, Clone)]
 pub struct Document {
@@ -12,15 +14,6 @@ pub struct Document {
     pub(crate) trailing: InternalString,
 }
 
-impl Default for Document {
-    fn default() -> Self {
-        Self {
-            root: Item::Table(Table::with_pos(Some(0))),
-            trailing: Default::default(),
-        }
-    }
-}
-
 impl Document {
     /// Creates an empty document
     pub fn new() -> Self {
@@ -46,6 +39,25 @@ impl Document {
             .expect("root should always be a table")
             .iter()
     }
+
+    /// Set whitespace after last element
+    pub fn set_trailing(&mut self, trailing: &str) {
+        self.trailing = trailing.to_owned();
+    }
+
+    /// Whitespace after last element
+    pub fn trailing(&self) -> &str {
+        self.trailing.as_str()
+    }
+}
+
+impl Default for Document {
+    fn default() -> Self {
+        Self {
+            root: Item::Table(Table::with_pos(Some(0))),
+            trailing: Default::default(),
+        }
+    }
 }
 
 impl FromStr for Document {
